@@ -5,23 +5,11 @@ from abc import ABC, abstractmethod
 
 import pandas as pd
 
-import matplotlib.pyplot as plt
 import numpy as np
-import torch.nn.functional as F
-
-from napoleontoolbox.neural_net import roll_multi_layer_lstm
 from napoleontoolbox.file_saver import dropbox_file_saver
-from napoleontoolbox.neural_net import roll_multi_layer_perceptron
-from napoleontoolbox.boosted_trees import roll_lightgbm
-from napoleontoolbox.features import features_type
 from napoleontoolbox.utility import weights
-from napoleontoolbox.utility import utility
 from napoleontoolbox.rebalancing import allocation
 
-import torch
-import torch.nn as nn
-
-
 
 class AbstractRunner(ABC):
     def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252):
@@ -49,8 +37,7 @@ class AbstractRunner(ABC):
         self.mdp_allocation = True
 
     @abstractmethod
-    def runTrial(self,saver, seed, sup, layers, epochs, n_past_features, n, s, whole_history, advance_feature, advance_signal,
-                 normalize, activation_string, convolution, lr_start, lr_type, low_bound, up_bound):
+    def runTrial(self,saver, seed,  n, s, low_bound, up_bound):
         pass
 
 
@@ -59,7 +46,9 @@ class SimpleEnsemblingRunner(AbstractRunner):
         try:
             self.wrappedRunTrial(saver, seed, n, s, low_bound, up_bound)
         except Exception as e:
-            print('To investigate and relaunch')
+            print('################# : To investigate and relaunch')
+            print('################# : To investigate and relaunch')
+            print('################# : To investigate and relaunch')
             print(e)
 
     def wrappedRunTrial(self, saver, seed,  n, s, low_bound, up_bound):
