@@ -113,7 +113,15 @@ class ParallelRunResultAnalyzer():
                     params = json.loads(run_json_string)
                     #salty = hashlib.sha256(run_json_string)
                     salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
-                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+str(params['normalization'])+salty
+                    if 'transaction_costs' in params.keys():
+                        transacs = str(params['transaction_costs'])
+                    else:
+                        transacs = ''
+                    if 'normalization' in params.keys():
+                        normas = str(params['normalization'])
+                    else:
+                        normas=''
+                    renaming_dictionary[col] = params['signal_type']+transacs+normas+salty
 
             results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
         return results_df
@@ -151,7 +159,15 @@ class ParallelRunResultAnalyzer():
                     params = json.loads(run_json_string)
                     #salty = hashlib.sha256(run_json_string)
                     salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
-                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+str(params['normalization'])+salty
+                    if 'transaction_costs' in params.keys():
+                        transacs = str(params['transaction_costs'])
+                    else:
+                        transacs = ''
+                    if 'normalization' in params.keys():
+                        normas = str(params['normalization'])
+                    else:
+                        normas=''
+                    renaming_dictionary[col] = params['signal_type']+transacs+normas+salty
 
             results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
         return results_df
