@@ -108,6 +108,28 @@ def reconstitute_signal_perf(data=None, initial_price = 1. , average_execution_c
     data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
     return data
 
+def reconstitute_prediction_perf(y_pred=None, y_true=None, initial_price = 1. , average_execution_cost = 7.5e-4 , transaction_cost = True, print_turnover = False):
+    if not isinstance(y_pred, pd.DataFrame):
+        y_pred=pd.DataFrame(y_pred)
+    data = y_pred
+    data.columns = ['signal']
+    if not isinstance(y_true, np.ndarray):
+        y_true = y_true.values
+
+    data['close_return']=y_true
+    data['turn_over'] = abs(data['signal'] - data['signal'].shift(-1).fillna(0.))
+    if print_turnover:
+        print('average hourly turn over')
+        print(data['turn_over'].sum() / len(data))
+    data['reconstituted_close'] = metrics.from_ret_to_price(data['close_return'],initial_price=initial_price)
+    data['non_adjusted_perf_return'] = data['close_return'] * data['signal']
+    if transaction_cost :
+        data['perf_return'] = data['non_adjusted_perf_return']- data['turn_over']*average_execution_cost
+    else :
+        data['perf_return'] = data['non_adjusted_perf_return']
+    data['reconstituted_perf'] = metrics.from_ret_to_price(data['perf_return'],initial_price=initial_price)
+    return data
+
 def compute_turn_over(data=None):
     return abs((data.signal - data.signal.shift(-1).fillna(0.))).mean()
 
